Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(234)

Unified Diff: ui/ozone/platform/drm/client_native_pixmap_factory_gbm.cc

Issue 2376293003: gpu: support RG_88 GpuMemoryBuffer (Closed)
Patch Set: resolve hubbe's review Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/ozone/gl/gl_image_ozone_native_pixmap.cc ('k') | ui/ozone/platform/drm/common/drm_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/ozone/platform/drm/client_native_pixmap_factory_gbm.cc
diff --git a/ui/ozone/platform/drm/client_native_pixmap_factory_gbm.cc b/ui/ozone/platform/drm/client_native_pixmap_factory_gbm.cc
index 06aada4e3175f1dc3659cf53de62dcef0b3a7211..6199e36f11a432930ad3987441a5b8425c805770 100644
--- a/ui/ozone/platform/drm/client_native_pixmap_factory_gbm.cc
+++ b/ui/ozone/platform/drm/client_native_pixmap_factory_gbm.cc
@@ -62,9 +62,10 @@ class ClientNativePixmapFactoryGbm : public ClientNativePixmapFactory {
#if defined(OS_CHROMEOS)
return
#if defined(ARCH_CPU_X86_FAMILY)
// Currently only Intel driver (i.e. minigbm and Mesa) supports R_8.
// crbug.com/356871
format == gfx::BufferFormat::R_8 ||
+ format == gfx::BufferFormat::RG_88 ||
#endif
format == gfx::BufferFormat::BGRA_8888;
#else
@@ -62,9 +62,10 @@ class ClientNativePixmapFactoryGbm : public ClientNativePixmapFactory {
return
#if defined(ARCH_CPU_X86_FAMILY)
- // Currently only Intel driver (i.e. minigbm and Mesa) supports R_8.
- // crbug.com/356871
+ // Currently only Intel driver (i.e. minigbm and Mesa) supports R_8
+ // and RG_88. crbug.com/356871
format == gfx::BufferFormat::R_8 ||
« no previous file with comments | « ui/ozone/gl/gl_image_ozone_native_pixmap.cc ('k') | ui/ozone/platform/drm/common/drm_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698